<?php
/**
 * Materialike Functions
 *
 * @package Materialike
 * @subpackage Materialike
 * @since Materialike
 */

/*
 * Include
 */
require( dirname( __FILE__ ) . '/plugin-update-checker/plugin-update-checker.php' );
require( dirname( __FILE__ ) . '/inc/theme-customize.php' );
require( dirname( __FILE__ ) . '/inc/theme-options.php' );
require( dirname( __FILE__ ) . '/inc/theme-widget.php' );

$pluginUpdateCheck = Puc_v4_Factory::buildUpdateChecker( 'https://modellax.net/downloads/updates/themes/materialike/update.json', __FILE__, 'materialike' );

/*
 * Setup Theme
 */
function materialike_setup_theme() {

	load_theme_textdomain( 'materialike', dirname( __FILE__ ) . '/languages' );

	add_theme_support( 'custom-header', materialike_custom_header_setting() );
	add_theme_support( 'widgets' );
	add_theme_support( 'menus' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_editor_style();
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );
	add_post_type_support( 'page', 'excerpt' );

}
add_action( 'after_setup_theme', 'materialike_setup_theme' );

/*
 * Add Widget
 */
function materialike_register_widget() {

	$arguments = materialike_custom_widget_setting();

	foreach ( $arguments as $key => $val )
		register_sidebar( $arguments[$key] );

}
add_action( 'widgets_init', 'materialike_register_widget' );

/*
 * Add Menu
 */
function materialike_register_menu() {

	$arguments = materialike_custom_menu_setting();

	register_nav_menus( $arguments );

}
add_action( 'after_setup_theme', 'materialike_register_menu' );

/*
 * Override Head Title
 */
/*
Official site is ban title support
function materialike_head_title( $separator ) {

	$separator = '|';

	return $separator;

}
add_filter( 'document_title_separator', 'materialike_head_title' );
*/

/*
 * Override WP Nav Menu
 */
function materialike_override_wp_nav_menu( $html ) {

	$html = preg_replace( '/\t/', '', $html );
	$html = preg_replace( '/\r\n|\n|\r/', '', $html );

	return $html;

}
add_filter( 'wp_nav_menu', 'materialike_override_wp_nav_menu' );

/*
 * Override Widget  * Require inc/theme-widget.php *
 */
function materialike_override_wp_widget() {

	register_widget( 'WP_Widget_Recent_Posts_Override' );
	register_widget( 'WP_Widget_Pages_Override' );

}
add_action( 'widgets_init', 'materialike_override_wp_widget' );

/*
 * Override WP List Categories
 */
function materialike_override_wp_list_categories( $html ) {

	$html = preg_replace( '/<\/a>\s*\((\d+)\)/', '<span class="post-count">($1)</span></a>', $html );

	return $html;

}
add_filter( 'wp_list_categories', 'materialike_override_wp_list_categories', 10, 1 );

/*
 * Override The Categories
 */
function materialike_override_the_category( $html ) {

	$html = preg_replace( '/\r\n|\n|\r/', '', $html );
	$html = preg_replace( '/\t/', '', $html );

	return $html;

}
add_filter( 'the_category', 'materialike_override_the_category', 10, 1 );

/*
 * Override WP Tag Cloud
 */
function materialike_override_wp_tag_cloud( $html, $param ) {

	$html = preg_replace( '/\r\n|\n|\r/', '', $html );
	$html = preg_replace( '/\t/', '', $html );
	$html = preg_replace( '/style=".+?"/', '', $html );

	return $html;

}
add_filter( 'wp_tag_cloud', 'materialike_override_wp_tag_cloud', 10, 2 );

/*
 * Override Get Archives Link
 */
function materialike_override_get_archives_link( $html ) {

	$html = preg_replace( '/<\/a>&nbsp;\((\d+)\)/','<span class="post-count">($1)</span></a>', $html );

	return $html;

}
add_filter( 'get_archives_link', 'materialike_override_get_archives_link', 10, 1 );

/*
 * Override WP List Pages
 */
function materialike_override_wp_list_pages( $html ) {

	$html = preg_replace( '/\t/', '', $html );
	$html = preg_replace( '/\r\n|\n|\r/', '', $html );
	$html = preg_replace( '/(page_item_has_children)/', 'menu-item-has-children \1', $html );
	$html = preg_replace( '/(<ul class.+?)(children)(.+?>)/', '\1sub-menu \2\3', $html );

	return $html;

}
add_filter( 'wp_list_pages', 'materialike_override_wp_list_pages' );

/*
 * Override Get Calendar
 */
function materialike_override_get_calendar( $html ) {

	$html = preg_replace( '/&laquo;|&raquo;/', '', $html );
	$html = preg_replace( '/(<td)(><a)/', '\1 class="has_link"\2', $html);
	$html = preg_replace( '/(<td.+?id=".+?")(><a)/', '\1 class="has_link"\2', $html );

	return $html;

}
add_filter( 'get_calendar', 'materialike_override_get_calendar', 10, 1 );

/*
 * Override The Password Form
 */
function materialike_override_password_form( $html ){

	$html = preg_replace( '~<input type="submit".+?>~', '<button type="submit" name="Submit" class="button">' . esc_attr_x( 'Enter', 'post password form' ) . '</button>', $html );

	return $html;

}
add_filter( 'the_password_form', 'materialike_override_password_form' );

/*
 * Override Comment Form Fields
 */
function materialike_override_comment_form_fields( $fields ) {

	$comment_field = $fields['comment'];

	unset( $fields['comment'] );

	$fields['comment'] = $comment_field;
  
	return $fields;

}
add_filter( 'comment_form_fields', 'materialike_override_comment_form_fields' );

/*
 * Override Comment Form Submit Button
 */
function materialike_override_comment_form_submit_button( $submit, $args ){

	$submit = '<button name="' . esc_attr( $args['name_submit'] ) . '" id="' . esc_attr( $args['id_submit'] ) . '" class="' . esc_attr( $args['class_submit'] ) . ' button comment-submit">'.esc_attr( $args['label_submit'] ) . '</button>';

	return $submit;

}
add_filter( 'comment_form_submit_button', 'materialike_override_comment_form_submit_button', 10, 2 );

/*
 * Override More Link
 */
function materialike_override_more_link() {

	return materialike_more_link( apply_filters( 'override_more_link_text', $text ) );

}
add_filter( 'the_content_more_link', 'materialike_override_more_link' );

/*
 * Override Excerpt Length
 */
function materialike_length_excerpt( $length ) {

     return 128;	

}
add_filter( 'excerpt_length', 'materialike_length_excerpt', 999 );

/*
 * Rewrite Tiny MCE Before Init
 */
function materialike_rewrite_tiny_mce_before_init( $init ) {

	echo '<style type="text/css">.mce-menu-item .mce-text{ font-size: 14px !important; }</style>';

	$init['block_formats'] =
		  __( 'Headline Level 1', 'materialike' ) . '=h1;'
		. __( 'Headline Level 2', 'materialike' ) . '=h2;'
		. __( 'Headline Level 3', 'materialike' ) . '=h3;'
		. __( 'Headline Level 4', 'materialike' ) . '=h4;'
		. __( 'Headline Level 5', 'materialike' ) . '=h5;'
		. __( 'Headline Level 6', 'materialike' ) . '=h6;'
		. __( 'Paragraph', 'materialike') . '=p;'
		. __( 'Preformatted Text', 'materialike' ) . '=pre;';

	$arguments = materialike_custom_editor_style_setting();

	$init['style_formats'] = json_encode( $arguments );

	return $init;

}
add_filter( 'tiny_mce_before_init', 'materialike_rewrite_tiny_mce_before_init' );

/*
 * Add MCE Buttons 1
 */
function materialike_add_tinymce_buttons( $tools ) {

	unset( $tools[array_search( 'link', $tools )] );
	unset( $tools[array_search( 'wp_adv', $tools )] );

	array_push( $tools, 'link' );
	array_push( $tools, 'unlink' );
	array_push( $tools, 'anchor' );
	array_push( $tools, 'wp_adv' );

	return $tools;

}
add_filter( 'mce_buttons', 'materialike_add_tinymce_buttons' );

/*
 * Add MCE Buttons 2
 */
function materialike_add_mce_buttons_2( $tools ) {

	array_unshift( $tools, 'table' );
	array_unshift( $tools, 'styleselect' );

	return $tools;

}
add_filter( 'mce_buttons_2', 'materialike_add_mce_buttons_2' );

/*
 * Add MCE External Plugins
 */
function materialike_add_mce_external_plugins( $plugins ) {

	$plugins['table']  = '//cdn.tinymce.com/4/plugins/table/plugin.min.js';
	$plugins['anchor'] = '//cdn.tinymce.com/4/plugins/anchor/plugin.min.js';

	return $plugins;

}
add_filter( 'mce_external_plugins', 'materialike_add_mce_external_plugins' );

/*
 * Allow Save Pre
 */
function materialike_allow_content_save_pre( $content ) {

	global $allowedposttags;

	$allow = array(
		'iframe' => array(
			'class'       => array(),
			'src'         => array(),
			'width'       => array(),
			'height'      => array(),
			'frameborder' => array(),
			'scrolling'   => array(),
		),
	);
 
 	array_push( $allowedposttags, $allow );
 
    return $content;

}
add_filter( 'content_save_pre', 'materialike_allow_content_save_pre' );

/*
 * Enqueue Scripts
 */
function materialike_enqueue_scripts() {

	wp_enqueue_script( 'materialike-js-agent', get_template_directory_uri() . '/js/agent.js' );
	wp_enqueue_script( 'materialike-js-wow', get_template_directory_uri() . '/js/wow.js' );
	wp_enqueue_script( 'materialike-js-anchorscroll', get_template_directory_uri() . '/js/anchorscroll.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-parallax', get_template_directory_uri() . '/js/parallax.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-navigator', get_template_directory_uri() . '/js/navigator.js', array( 'jquery' ) );

	wp_enqueue_style( 'materialike-css', get_stylesheet_uri() );
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'materialike-css-glyphicon', get_template_directory_uri() . '/css/glyphicons.css' );
	wp_enqueue_style( 'materialike-css-icomoon', get_template_directory_uri() . '/css/icomoon.css' );
	wp_enqueue_style( 'materialike-css-animate', get_template_directory_uri() . '/css/animate.css' );
	wp_enqueue_style( 'materialike-css-parallax', get_template_directory_uri() . '/css/parallax.css' );
	wp_enqueue_style( 'materialike-css-navigator', get_template_directory_uri() . '/css/navigator.css' );

}
add_action( 'wp_enqueue_scripts', 'materialike_enqueue_scripts' );

/*
 * Template Function - Replace Char
 */
function materialike_replace_char( $origin = '', $keyword = '', $replace = '' ) {

	$string = '';

	if( '' != $origin && '' != $keyword && '' != $replace )
		$string = preg_replace( '~' . $keyword . '~', $replace, $origin );

	return $string;

}

/*
 * Template Function - Layout
 */
function materialike_layout( $mode = 'before', $sidebarname = '' ){

	$layout = get_theme_mod('layout_preset', 'sidebar-right');

	if( 'sidebar-right' == $layout || 'sidebar-left' == $layout || 'sidebar-none' == $layout ) {

		if( 'before' == $mode ){

			echo '<div class="inside-contents';
			if ( 'sidebar-none' == $layout ) {
				echo ' round-none';
			} elseif ( 'sidebar-left' == $layout ) {
				echo ' round-right';
			} elseif ( 'sidebar-right' == $layout ) {
				echo ' round-left';
			}
			echo '">';

			echo '<div class="inside-contents-inner">';

		} elseif ( 'after' == $mode ) {

			echo '</div>';

			if( 'sidebar-none' != $layout ) {

				echo '</div>';
				echo '<div class="inside-sidebar';
				if ( 'sidebar-left' == $layout ) {
					echo ' round-left';
				} elseif ( 'sidebar-right' == $layout ) {
					echo ' round-right';
				}
				echo '">';

				if ( '' != $sidebarname )
					get_sidebar( $sidebarname );
				else
					get_sidebar();

			}

			echo '</div>';

		}

	}

}

/*
 * Template Function - Logo
 */
function materialike_logo( $show_title = 'show' ) {

	$title = get_bloginfo( 'name' );
	$image = get_header_image();

	$string = '';

	if ( '' != $title ) {

		$string .= '
		<div class="site">
			<h1 class="logo"><a href="' . esc_url( get_home_url() ) . '">';
	
		if ( ! empty( $image ) )
			$string .= '<img src="' . esc_url( get_header_image() ) . '" alt="' . esc_html( get_bloginfo( 'name' ) ) . '" class="logo-image" />';

		if ( empty( $image ) || 'none' != $show_title ) 
			$string .= esc_html( get_bloginfo( 'name' ) );
	
		$string .= '</a></h1>
		</div>';

	}

	echo $string;

}

/*
 * Template Function - Description
 */
function materialike_description() {

	$description = '' != get_theme_mod( 'description', '' ) ? get_theme_mod( 'description', '' ) : get_bloginfo( 'description' );

	$string = '';

	if ( '' != $description ) {
		$string .= '
		<div class="catchcopy">';
		$string .= '
			<h1 class="description">' . esc_html( $description ) . '</h1>';
		$string .= '
		</div>';
	}

	echo $string;

}

/*
 * Template Function - Nav Menu
 */
function materialike_nav_menu( $place = 'global' ){

	$arguments = array(
		'menu_class' => 'menu xclear',
		'link_before' => '<span class="menu-inner">', 
		'link_after' => '</span>',
		'container' => 'ul',
		'theme_location' => $place,
	);

	wp_nav_menu( $arguments );

}

/*
 * Template Function - Copyright
 */
function materialike_copyright() {

	$copyright = '' != get_theme_mod( 'copyright', '' ) ? get_theme_mod( 'copyright', '' ) : 'Copyright (c) ' . get_bloginfo( 'name' ) . ' All rights reserved.';

	$string = '';
	
	$string .= '
	<div class="assert">
		<small class="copyright">' . esc_html( $copyright ) . '</small>
	</div>';

	echo $string;

}

/*
 * Template Function - Single Title
 */
function materialike_single_title( $home_archive_string = '' ) {

	if ( is_front_page() ) {

		if ( is_page() )
			single_post_title();
		else
			echo $home_archive_string;

	} elseif ( is_page() || is_attachment() || is_single() || is_singular() ) {

		single_post_title();

	} elseif ( is_tax() || is_category() || is_tag() ) {

		if ( is_category () ) {
			echo '<span class="tax">';
			_e( 'Category', 'materialike' );
			echo '</span>';
		} elseif ( is_tag () ) {
			echo '<span class="tax">';
			_e( 'Tag', 'materialike' );
			echo '</span>';
		}

		echo '<span class="term">';
		single_term_title();
		echo '</span>';

	} elseif ( is_date() ) {

		if ( is_year() ) {
			echo get_the_date( _x( 'Y', 'yearly archives date format' ) );
		} elseif ( is_month() ) {
			echo get_the_date( _x( 'F Y', 'monthly archives date format' ) );
		} elseif ( is_day() ) {
			echo get_the_date();
		}

	} elseif ( is_search() ) {
	
		global $wp_query;

		_e( 'Search Result', 'materialike' );
		
		echo '<span class="found">' . $wp_query->found_posts . '<span class="hit">' . __( 'Hit', 'materialike' ) . '</span>' . '</span>';

		echo '<span class="keywords">' . ( '' != get_search_query() ? esc_html( get_search_query() ) : __( 'No keywords', 'materialike' ) ) . '</span>';

	} elseif ( is_404() ) {

		_e( 'Not Found', 'materialike' );

	} elseif ( is_author() ) {

		_e( 'Author', 'materialike' );

		echo '<span class="author">' . get_the_author() . '</span>';

	} elseif ( is_archive() ) {

		$post_type_object = get_post_type_object( get_post_type() );

		if ( isset( $post_type_object ) ) {

			echo $post_type_object->labels->singular_name;

		}

	}

}

/*
 * Template Function - Single Attribute
 */
function materialike_single_attr() {

	if ( is_front_page() ) {

		if ( is_page() )
			echo 'page';
		else
			echo 'home';

	} elseif ( is_page() ) {

		echo 'page';

	} elseif ( is_attachment() ) {

		echo 'attachment';

	} elseif ( is_single() && is_singular( 'post' ) ) {

		echo 'single';

	} elseif ( is_single() || is_singular() ) {

		echo 'singular';

	} elseif ( is_category() ) {

		echo 'categories';

	} elseif ( is_tag() ) {

		echo 'tags';

	} elseif ( is_tax() ) {

		echo 'taxonomies';

	} elseif ( is_date() ) {

		if ( is_year() ) {
			echo 'year';
		} elseif ( is_month() ) {
			echo 'month';
		} elseif ( is_day() ) {
			echo 'day';
		}

	} elseif ( is_search() ) {
	
		echo 'search';

	} elseif ( is_404() ) {
	
		echo 'notfound';

	} elseif ( is_author() ) {

		echo 'author';

	} elseif ( is_archive() ) {

		echo 'archive';

	}

}

/*
 * Template Function - Breadlist
 */
function materialike_breadlist( $greater = '', $outside = 'outside', $home = '', $home_archive_string = '' ) {

	$breadlist = '';
	$base      = '<li class="breadlist-home"><a href="' . esc_url( get_home_url() ) . '" class="breadlist-home-link"><span class="breadlist-home-string">' . ( '' != $home ? $home : __( 'HOME', 'materialike' ) ) . '</span></a></li>';
	$greater   = '' != $greater ? $greater : '<span class="breadlist-greater"><span class="breadlist-greater-string">&gt;</span></span>';

	if ( is_front_page() ) {

		$string = $base;

		$string = $base . ( '' != $home_archive_string ? '<li>' . $greater . esc_html( $home_archive_string ) . '</li>' : '' );

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_page() || is_attachment() ) {

		$string = '';
		$post = get_post();

		$string = '<li>' . $greater . esc_html( $post->post_title ) . '</li>';

		if ( 0 != $post->post_parent ) {

			$entry = get_post( $post->ID );

			while ( 0 != $entry->post_parent ) {
				$entry = get_post( $entry->post_parent );
				$string = '<li>' . $greater . '<a href="' . esc_url( get_permalink( $entry->ID ) ) . '">' . esc_html( $entry->post_title ) . '</a></li>' . $string;
			}

		}

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_single() || is_singular() ) {
		$n = 0;
		$array = array();

		$terms = array();

		$taxonomies = array_diff( get_object_taxonomies( get_post_type(), 'names' ), array( 'post_format' ) );
		$taxonomies = array_values( $taxonomies );

		foreach ( $taxonomies as $val) {

			$terms = get_the_terms( get_the_ID(), $val );
			
			if( $terms ) {

				foreach ( $terms as $term ) {

					$array[$n] = '<li>' . $greater . '<a href="' . esc_url( get_term_link( $term->term_id ) ) . '">' . esc_html( $term->name ) . '</a></li>';

					if ( 0 != $term->parent ) {

						$alone = get_term( $term->term_id );

						while ( 0 != $alone->parent ) {
							$alone = get_term( $alone->parent );
							$array[$n] = '<li>' . $greater . '<a href="' . esc_url( get_term_link( $alone->term_id ) ) . '">' . esc_html( $alone->name ) . '</a></li>' . $array[$n];
						}

					}

					$array[$n] = $base . $array[$n] . '<li>' . $greater . esc_html( get_the_title() ) . '</li>';

					$n++;

				}

			} else {

				if ( 0 == $n )
					$array[$n] = $base . '<li>' . $greater . esc_html( get_the_title() ) . '</li>';

			}

		}

		for ( $i = 0; $i <= count( $array ) - 1; $i++ )
			$breadlist .= '<ul>' . $array[$i] . '</ul>';
		
	} elseif ( is_tax() || is_category() || is_tag() ) {

		$string = '';
		$term = get_term( get_queried_object()->term_id );

		$string = '<li>' . $greater . '<a href="' . esc_url( get_term_link( $term->term_id ) ) . '">' . esc_html( $term->name ) . '</a></li>';

		if ( 0 != $term->parent ) {

			$alone = get_term( $term->term_id );

			while ( 0 != $alone->parent ) {
				$alone = get_term( $alone->parent );
				$string = '<li>' . $greater . '<a href="' . esc_url( get_term_link( $alone->term_id ) ) . '">' . esc_html( $alone->name ) . '</a></li>' . $string;
			}

		}

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_date() ) {

		if ( is_year() ) {
			$string = '';
			$string = '<li>' . $greater . get_the_date( _x( 'Y', 'yearly archives date format') ) . '</li>';
		} elseif ( is_month() ) {
			$string = '';
			$string = '<li>' . $greater . get_the_date( _x( 'F Y', 'monthly archives date format') ) . '</li>';
		} elseif ( is_day() ) {
			$string = '';
			$string = '<li>' . $greater . get_the_date() . '</li>';
		}

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_search() ) {

		$string = '';
			
		$string = '<li>' . $greater . __( 'Search Result', 'materialike' ) . '<span class="keywords">' . ( '' != get_search_query() ? esc_html( get_search_query() ) : __( 'No keywords', 'materialike' ) ) . '</span>' . '</li>';

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_404() ) {

		$string = '';
			
		$string = '<li>' . $greater . __( 'Not Found', 'materialike' ) . '</li>';

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_author() ) {

		$string = '';
			
		$string = '<li>' . $greater . __( 'Author', 'materialike' ) . '<span class="author">' . get_the_author() . '</span>' . '</li>';

		$string = $base . $string;

		$breadlist .= '<ul>' . $string . '</ul>';

	} elseif ( is_archive() ) {

		$string = '';

		$post_type_object = get_post_type_object( get_post_type() );

		if( isset( $post_type_object ) ){

			$string = '<li>' . $greater . $post_type_object->labels->singular_name . '</li>';

			$string = $base . $string;

			$breadlist .= '<ul>' . $string . '</ul>';

		}

	}
	
	if ( '' != $breadlist )
		echo '<nav class="breadlist">' . ( 'inside' == $outside ? '<div class="inside">' . $breadlist . '</div>' : $breadlist ) . '</nav>';

}

/*
 * Template Function - On Show Comments
 */
function materialike_on_show_comments(){

	$status = get_option('materialike_show_comments') ? get_option('materialike_show_comments') : 'enable';

	if( 'enable' != $status )
		return false;
	else
		return true;

}

/*
 * Template Function - Pagenation
 */
function materialike_pagenation() {

	global $wp_query;

	$arguments = array(
		'base'      => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
		'format'    => '?paged=%#%',
		'prev_next' => true,
		'prev_text' => '<span class="prev-string">&lt;</span>',
		'next_text' => '<span class="next-string">&gt;</span>',
		'current'   => max( 1, get_query_var('paged') ),
		'type'      => 'plain',
		'total'     => $wp_query->max_num_pages,
	);
	$pager = paginate_links( $arguments );

	if ( isset( $pager ) ) {

		$pager = preg_replace( '/\t/', '', $pager );
		$pager = preg_replace( '/\r\n|\n|\r/', '', $pager );

		$pager = '
		<nav class="maneuver">
			<div class="pagenation">
				' . $pager . '
			</div>
		</nav>';

	}

	echo $pager;

}

/*
 * Template Function - Entries Pager
 */
function materialike_entries_pager() {

	$pager = '';

	if ( get_next_posts_link() || get_previous_posts_link() ) {

		if ( get_previous_posts_link() )
			$pager .= '<li class="next">' . str_replace( '<a', '<a class="pager-next"', get_previous_posts_link( '<span class="next-string">&lt;</span>' ) ) . '</li>';

		if ( get_next_posts_link() )
			$pager .= '<li class="prev">' . str_replace( '<a', '<a class="pager-prev"', get_next_posts_link( '<span class="prev-string">&gt;</span>' ) ) . '</li>';

		$pager = '
		<nav class="maneuver">
			<div class="pager pager-entries">
				<ul>
					' . $pager . '
				</ul>
			</div>
		</nav>';

	}

	echo $pager;

}

/*
 * Template Function - Entry Pager
 */
function materialike_entry_pager() {

	$pager = '';

	if ( get_previous_post_link() || get_next_post_link() ) {

		if ( get_next_post_link() )
			$pager .= '<li class="next">' . str_replace( '<a', '<a class="pager-next"', get_next_post_link( '%link' ) ) . '</li>';

		if ( get_previous_post_link() )
			$pager .= '<li class="prev">' . str_replace( '<a', '<a class="pager-prev"', get_previous_post_link( '%link' ) ) . '</li>';

		$pager = '
		<nav class="maneuver">
			<div class="pager pager-entry">
				<ul>
					' . $pager . '
				</ul>
			</div>
		</nav>';

	}

	echo $pager;

}

/*
 * Template Function - Entry Breaker
 */
function materialike_entry_breaker() {

	echo '<nav class="manuver">';

	wp_link_pages( array(
		'before'         => '<div class="breaker">',
		'after'          => '</div>',
		'link_before'    => '<span class="break-numbers">',
		'link_after'     => '</span>',
		'pagelink'       => '%',
	) );

	echo '</nav>';

}

/*
 * Template Function - Image Pager
 */
function materialike_image_pager() {

	echo '
		<nav class="maneuver">
			<div class="pager pager-media">
				<ul>
					<li class="next">';

	next_image_link( false, '<span class="next-string">&lt;</span>' );

	echo '
					</li>
					<li class="prev">';

	previous_image_link( false, '<span class="prev-string">&gt;</span>' );

	echo '
					</li>
				</ul>
			</div>
		</nav>';

}

/*
 * Template Function - Get Image
 */
function materialike_get_image( $image_id = '', $entity = 'do', $class = '' ) {

	$thumbnail = '';
	$image     = false;

	if ( '' != $image_id ) {

		$image = wp_get_attachment_image_src( $image_id, 'full' );
		$image['alt'] = get_post_meta( $image_id, '_wp_attachment_image_alt', true );

		if( isset( $image[0] ) ) {
			if( 'none' != $entity )
				$thumbnail = '<figure class="' . ( '' != $class ? $class : 'image' ) . '"><img src="' . esc_url( $image[0] ) . '" alt="' . esc_html( $image['alt'] ) . '" /></figure>';
			else
				$thumbnail = '<figure class="viewer' . ( '' != $class ? ' ' . $class : ' image' ) . '" style="background-image: url(' . esc_url( $image[0] ) . ');"><span class="viewer-inner"></span></figure>';
		}
	
	}

	return $thumbnail;

}

/*
 * Template Function - Get Media
 */
function materialike_get_media( $media_id = '', $video_loop = 'once', $video_autoplay = 'do', $video_class = '', $image_entity = 'do', $image_class = '' ) {

	$thumbnail = '';
	$media     = false;

	if ( '' != $media_id ) {

		$media = wp_get_attachment_url( $media_id );

		if ( materialike_is_media_video( $media_id ) ) {

			$thumbnail = '<video class="' . ( '' != $video_class ? ' ' . $video_class : 'video' ) . '" src="' . esc_url( $media ) . '"' . ( 'loop' != $video_loop ? '' : ' loop' ) . '' . ( 'none' != $video_autoplay ? ' autoplay' : '' ) . ' muted playsinline></video>';

		} elseif ( preg_match( '~\.jpg$|\.jpeg$|\.gif$|\.png$~', $media ) ) {

			$thumbnail = materialike_get_image( $media_id, $image_entity, $image_class );

		}
	
	}

	return $thumbnail;

}

/*
 * Template Function - The Image
 */
function materialike_the_image( $image_id = '', $entity = 'do', $class = '' ) {

	echo materialike_get_image( $image_id, $entity, $class );

}

/*
 * Template Function - The Media
 */
function materialike_the_media( $media_id = '', $video_loop = 'once', $video_autoplay = 'do', $video_class = '', $image_entity = 'do', $image_class = '' ) {

	echo materialike_get_media( $media_id, $video_loop, $video_autoplay, $video_class, $image_entity, $image_class );

}

/*
 * Template Function - Is Media Video
 */
function materialike_is_media_video( $media_id = '' ) {

	$video = false;

	if( '' != $media_id ){

		if( preg_match( '~\.mp4$|\.webm$~', wp_get_attachment_url( $media_id ) ) )
			$video = true;

	}

	return $video;

}

/*
 * Template Function - Entry Eyecatch
 */
function materialike_entry_eyecatch( $entity = 'do', $link = '', $text = '', $link_class = '', $thumbnail_class = '' ) {

	$thumbnail = '';

	if( has_post_thumbnail() ){

		$thumbnail = materialike_get_image( get_post_thumbnail_id(), $entity, $thumbnail_class );

		if( '' != $link ) {
			if( 'none' == $entity ) {
				$thumbnail .= '' != $text ? '<span class="post-image-text">' . $text . '</span>' : '';
			}
			$thumbnail = '<a href="' . esc_url( $link ) . '" class="post-image viewerout' . ( '' != $link_class ? ' ' . $link_class : '' ) . '">' . $thumbnail . '</a>';
		} else {
			$thumbnail = '<a class="post-image' . ( '' != $link_class ? ' ' . $link_class : '' ) . '">' . $thumbnail . '</a>';
		}

	}

	echo $thumbnail;

}

/*
 * Template Function - More Link  * In use: Override More Link  *
 */
function materialike_more_link( $text = '', $class = '' ) {

	echo '<p class="more"><a href="' . esc_url( get_the_permalink() ) . '" class="' . ( '' != $class ? $class : 'more-link' ) . '">' . ( '' != $text ? esc_html( $text ) : __( 'more', 'materialike' ) ) . '</a></p>';

}

/*
 * Template Function - The Category  * Fix Format Tags *
 */
function materialike_the_category() {

	the_category();

}

/*
 * Template Function - The Category  * Fix Format Categories *
 */
function materialike_the_tags() {

	the_tags('<ul class="post-tags"><li>', '</li><li>', '</li></ul>');

}

/*
 * Template Function - Attachment Meta
 */
function materialike_attachment_meta() {

	$metadata = wp_get_attachment_metadata();

	$property = '';

	if ( $metadata ) {

		$property .= '<div class="attachmentprop">';
		$property .= '<span class="attachmentprop-caption">' . __( 'Full size', 'materialike' ) . '</span>';
		$property .= '<span class="attachmentprop-size">' . absint( $metadata['width'] ) . '&nbsp;x&nbsp;' . absint( $metadata['height'] ) . '</span>';
		$property .= '</div>';
	}

	echo $property;

}

/*
 * Theme Defined Functions
 */

/** Custom Header Setting **/
function materialike_custom_header_setting() {

	return array(
		'default-image'  => '',
		'random-default' => false,
		'header-text'    => false,
		'width'          => 512,
		'height'         => 384,
		'flex-width'     => true,
		'flex-height'    => true,
	);

}

/** Custom Footer Setting **/
function materialike_custom_footer_setting() {

	return array(
		'width'          => 512,
		'height'         => 384,
		'flex_width'     => true,
		'flex_height'    => true,
	);

}

/** Custom Widget Setting **/
function materialike_custom_widget_setting() {

	return array(
		'side' => array(
			'name'          => __( 'Sidebar', 'materialike' ),
			'id'            => 'sidebar-1',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="title title-widget"><span class="title-inner">',
			'after_title'   => '</span></h3>'
		),
	);

}

/** Custom Menu Setting **/
function materialike_custom_menu_setting() {

	return array(
		'global'      => __( 'Global Navigation', 'materialike' ),
		'footer'      => __( 'Footer Navigation', 'materialike' ),
		'footer1line' => __( 'Footer 1 Line Navigation', 'materialike' ),
	);

}

/** Custom Editor Style Setting **/
function materialike_custom_editor_style_setting() {

	return array(
		array(
			'title'   => __( 'Clear Around', 'materialike' ),
			'block'   => 'div',
			'classes' => 'vclear',
		),
		array(
			'title'   => __( 'Link Button', 'materialike' ),
			'selector' => 'a',
			'classes' => 'button ripple shade-level-3',
		),
		array(
			'title'   => __( 'Font Size XL', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-xl',
		),
		array(
			'title'   => __( 'Font Size LL', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-ll',
		),
		array(
			'title'   => __( 'Font Size L', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-l',
		),
		array(
			'title'   => __( 'Font Size M', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-m',
		),
		array(
			'title'   => __( 'Font Size S', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-s',
		),
		array(
			'title'   => __( 'Font Size SS', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-ss',
		),
		array(
			'title'   => __( 'Font Size XS', 'materialike' ),
			'inline'  => 'span',
			'classes' => 'fs-xs',
		),
	);

}

/** Add Enqueue Scripts **/
function materialike_add_enqueue_scripts() {

	wp_enqueue_script( 'materialike-js-loading', get_template_directory_uri() . '/js/loading.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-ripple', get_template_directory_uri() . '/js/ripple.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-editorbuttonize', get_template_directory_uri() . '/js/editorbuttonize.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-mimicry', get_template_directory_uri() . '/js/mimicry.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-modalnav', get_template_directory_uri() . '/js/modalnav.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-activeroll', get_template_directory_uri() . '/js/activeroll.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-header', get_template_directory_uri() . '/js/header.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-menunav', get_template_directory_uri() . '/js/menunav.js', array( 'jquery' ) );
	wp_enqueue_script( 'materialike-js-searchask', get_template_directory_uri() . '/js/searchask.js', array( 'jquery' ) );
	wp_enqueue_style( 'materialike-css-loading', get_template_directory_uri() . '/css/loading.css' );
	wp_enqueue_style( 'materialike-css-ripple', get_template_directory_uri() . '/css/ripple.css' );
	wp_enqueue_style( 'materialike-css-modalnav', get_template_directory_uri() . '/css/modalnav.css' );
	wp_enqueue_style( 'materialike-css-header', get_template_directory_uri() . '/css/header.css' );
	wp_enqueue_style( 'materialike-css-menunav', get_template_directory_uri() . '/css/menunav.css' );
	wp_enqueue_style( 'materialike-css-searchask', get_template_directory_uri() . '/css/searchask.css' );

}
add_action( 'wp_enqueue_scripts', 'materialike_add_enqueue_scripts' );

/** Expand The Content **/
function materialike_expand_the_content( $content ) {

	if ( is_single() ){
		$content = preg_replace( '~(<span id="more-.+?"></span>)~', '\1' . '<span class="more-expand">' . get_theme_mod( 'post_more', '' ) . '</span>', $content );

		$content .= get_theme_mod( 'post_end', '' );
	}

	return $content;

}
add_filter( 'the_content', 'materialike_expand_the_content' );

/** Comment Reply Link **/
function materialike_comment_reply_link( $html ) {

	$html = preg_replace( '~<div class="reply">~', '<div class="reply droptask"><div class="dropmenu">', $html );
	$html = preg_replace( '~</div>~', '</div></div>', $html );
	$html = preg_replace( '~<a(.+?)class=\'(.+?)\'(.+?)~', '<div class="dropmenu-opener"></div><ul class="dropmenu-list armored shade-level-2"><li><a\1class=\'\2 ripple\'\3', $html );
	$html = preg_replace( '~</a>"~', '</a></li></ul>', $html );

	return $html;

}
add_filter( 'comment_reply_link', 'materialike_comment_reply_link' );

/** Reset Adminbar HTML **/
function materialike_reset_adminbar_html() {

	echo '<style type="text/css">html{margin-top: 0 !important;}</style>';

}
add_action( 'admin_bar_menu', 'materialike_reset_adminbar_html' );

/** Read Scripts **/
function materialike_read_scripts() {

	$prepend = array(
		'searchask'   => materialike_whatsearch_name(),
		'filecaption' => __( 'Select file', 'materialike' ),
	);

	$string = <<<EOT
<script type="text/javascript">
(function($){

	$(document).ready(function(){
		$('a[href]').anchorScroll();
		$('.loading').loading();
		$('input, textarea, select').mimicry({fileCaption: '{$prepend['filecaption']}'});
		$('.editor button').editorbuttonize({with: 'ripple shade-level-3'});
		$('.widget_text button, .widget_html button').editorbuttonize({with: 'ripple shade-level-3'});
		$('.navigator').navigators();
		$('.parallax').parallax();
		$('.dropmenu').modalnav();
		$('.gallery').activeroll({ frame: 30, position: 75, hover: true, hold: true, column:{ normal: [0, 1]} });
		$('#header').header({spacing: '[class^="entries"] > :first-child'});
		$('.searchask').searchask({header: '#header .signature', message:'{$prepend['searchask']}'});
		$('.navigation-global').menunav({opener: '.signature'});
		$('.navigation-global li.menu-item-has-children').subnav();
		$('.ripple').ripple();
		$('.navigation-global a, .navigation-footer a, .navigation-footer-1-line a').ripple();
		$('.widget_categories a, .widget_pages a, .widget_nav_menu > div a, .widget_archive a, .widget_recent_entries a, .widget_calendar a, .widget_tag_cloud a, .widget_rss > ul a').ripple();
		$('.pagenation a, .pager a, .breaker a').ripple();
		$('.menunav-switch-open').ripple();
	});

})(jQuery);
</script>
EOT;

	echo preg_replace( '/\r\n|\n|\r|\t/', '', $string );

}
add_action('wp_head', 'materialike_read_scripts');

/** Loading Script **/
function materialike_loading_script(){

	echo '
<script type="text/javascript">document.write(\'<div class="loading"><div class="bar"></div></div>\');</script>';

}

/** Loading Script **/
function materialike_navigator_script(){

	$home = ( ! is_front_page() || ( is_front_page() && 1 < get_query_var( 'paged', 1 ) ) ) ? '<a href="' . esc_url( get_home_url() ) . '" class="home button button-icon ripple shade-level-2"></a>' : '';

	echo '
<script type="text/javascript">
document.write(\'<div class="navigator">' . $home . '<a href="#container" class="top button button-icon ripple shade-level-2"></a><a href="#footer" class="bottom button button-icon ripple shade-level-2"></a></div>\');
</script>';

}

/** Print Headscript **/
function materialike_print_headscript() {

	echo get_theme_mod( 'headscript', '' );

}
add_action('wp_head', 'materialike_print_headscript', 99);

/** Home Posts Title **/
function materialike_home_posts_title( $echo = true ) {

	$string = '';

	if ( is_front_page() ) {

		if( 2 > get_query_var( 'paged', 1 ) ){

			$string = materialike_get_recent_posts_title();

		} else {

			$string = materialike_get_below_posts_title();

		}

	}

	if( $echo )
		echo $string;
	else
		return $string;

}

/** Get Recent Posts Text **/
function materialike_get_recent_posts_title() {

	$string = '';

	if( '' != get_theme_mod( 'entries_title', '' ) )
		$string = esc_html( get_theme_mod( 'entries_title', '' ) );
	else
		$string = __( 'Recent Entries', 'materialike' );

	return $string;

}

/** Get Below Posts Text **/
function materialike_get_below_posts_title() {

	$string = '';

	if( '' != get_theme_mod( 'below_entries_title', '' ) )
		$string = esc_html( get_theme_mod( 'below_entries_title', '' ) );
	else
		$string = __( 'Below Entries', 'materialike' );

	return $string;

}

/** More Name **/
function materialike_more_name( $echo = false ) {

	$string = '';

	if ( '' != get_theme_mod( 'voc_more', '' ) )
		$string = esc_html( get_theme_mod( 'voc_more', '' ) );
	else
		$string = __( 'more', 'materialike' );

	if( $echo )
		echo $string;
	else
		return $string;

}

/** Detail Name **/
function materialike_detail_name( $echo = false ) {

	$string = '';

	if ( '' != get_theme_mod( 'voc_detail', '' ) )
		$string = esc_html( get_theme_mod( 'voc_detail', '' ) );
	else
		$string = __( 'Detail', 'materialike' );

	if( $echo )
		echo $string;
	else
		return $string;

}

/** Read More Name **/
function materialike_read_more_name( $echo = false ) {

	$string = '';

	if ( '' != get_theme_mod( 'voc_readmore', '' ) )
		$string = esc_html( get_theme_mod( 'voc_readmore', '' ) );
	else
		$string = __( 'Read more', 'materialike' );

	if( $echo )
		echo $string;
	else
		return $string;

}

/** Whatsearch Name **/
function materialike_whatsearch_name( $echo = false ) {

	$string = '';

	if ( '' != get_theme_mod( 'voc_whatsearch', '' ) )
		$string = esc_html( get_theme_mod( 'voc_whatsearch', '' ) );
	else
		$string = __( 'What would you like to search?', 'materialike' );

	if( $echo )
		echo $string;
	else
		return $string;

}

/** Extra Descrioption **/
function materialike_extra_description() {

	if ( 'none' != get_theme_mod( 'description_show', 'show' ) )
		materialike_description();

}

/** Extra Logo **/
function materialike_extra_logo() {

	materialike_logo( get_theme_mod( 'logoafter', 'show' ) );

}

/** Page Eyecatch **/
function materialike_page_eyecatch( $entity = 'do', $class = '' ) {

	if( has_post_thumbnail() ){

		echo materialike_get_image( get_post_thumbnail_id(), $entity, $class );

	} else {

		echo materialike_the_image( get_theme_mod( 'page_image', '' ), $entity, $class );

	}

}

/** Footer Logo **/
function materialike_footer_logo() {

	$image = wp_get_attachment_image_src( get_theme_mod( 'footer_image', '' ), '' );

	if ( isset( $image[0] ) ) {

		echo '<h2 class="logo"><a href="' . esc_url( get_home_url() ) . '"><img src="' . esc_url( $image[0] ) . '" alt="' . esc_html( get_bloginfo( 'name' ) ) . '" />' . ( 'none' != get_theme_mod( 'logoafter', 'show' ) ? esc_html( get_bloginfo( 'name' ) ) : '' ) . '</a></h2>';

	} else {

		echo '<h2 class="logo"><a href="' . esc_url( get_home_url() ) . '">' . esc_html( get_bloginfo( 'name' ) ) . '</a></h2>';

	}

}

/** Site About **/
function materialike_site_about() {

	if( '' != get_theme_mod( 'about', '' ) )
		echo '<address class="about">' . preg_replace( '/\n/', '<br />', esc_html( get_theme_mod( 'about', '' ) ) ) . '</address>';

}

/** Excerpt Search **/
function materialike_search_excerpt( $length = 96, $more = '[...]', $echo = true ) {

	$string = get_post();

	$string = $string->post_content;

	if ( is_search() ) {

		$string = preg_replace( '/\r\n|\n|\r/', '', $string );
		$string = preg_replace( '/\t/', '', $string );

		$string = preg_replace( '~<form.+?class="post-password-form".+?</form>~', __( 'This is password protected.', 'materialike' ), $string );

		$string = strip_tags( $string );

		$more = $length < mb_strlen($string) ? $more : '';

		$string = mb_substr( $string, 0, $length );
		
		if( '' != get_search_query() )
			$string = preg_replace( '/(' . esc_html( get_search_query() ) . ')/', '<span class="keywords">\0</span>', $string ) . __($more, 'materialike' );

	}

	if( $echo )
		echo '<p class="excerpt">' . $string . '</p>';
	else
		return $string;

}
