<?php
/**
 * Materialike Theme Options
 *
 * @package Materialike
 * @subpackage Materialike
 * @since Materialike
 */

/*
 * Load Media Upload Script
 */
function materialike_load_media_upload_script() {

	if ( materialike_allow_admin_script() ) {

		wp_register_script( 'materialike-media-upload', get_template_directory_uri() . '/inc/js/media-upload.js', array( 'jquery' ), false, true );
		wp_enqueue_media();
		wp_enqueue_script( 'materialike-media-upload' );

	}

}
add_action( 'admin_print_scripts', 'materialike_load_media_upload_script' );

/*
 * Load Media Color Script
 */
function materialike_load_color_picker_script() {

	if ( materialike_allow_admin_script() ) {

		wp_register_script( 'materialike-color-picker', get_template_directory_uri() . '/inc/js/color-picker.js', array( 'wp-color-picker' ), false, true );
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'materialike-color-picker' );

	}

}
add_action( 'admin_print_scripts', 'materialike_load_color_picker_script' );

/*
 * Load jQuery UI Tabs Script
 */
function materialike_load_jquery_ui() {

	if ( materialike_allow_admin_script() ) {

		wp_enqueue_script( 'jquery-ui-tabs' );

    }

}
add_action('wp_print_scripts', 'materialike_load_jquery_ui');

/*
 * Load Select By Script
 */
function materialike_load_selectby() {

	if ( materialike_allow_admin_script() ) {

		wp_enqueue_script( 'materialike-js-selectby', get_template_directory_uri() . '/inc/js/selectby.js', array( 'jquery' ) );
		wp_enqueue_style( 'materialike-css-selectby', get_template_directory_uri() . '/inc/css/selectby.css' );

    }

}
add_action('wp_print_scripts', 'materialike_load_selectby');

/*
 * Allow Admin Script
 */
function materialike_allow_admin_script() {

	if ( isset($_GET['page']) ) {

		if( $_GET['page'] == 'materialike_theme_options' )
			return true;

	} else {

		return false;

	}

}

/*
 * Set Media Upload
 */
function materialike_set_media_upload( $name = '', $value = '', $mtype = 'image' ) {

?>
<div class="materialike-media-parent">
	<input type="hidden" name="<?php echo $name; ?>" value="<?php echo $value; ?>" class="materialike-media-holder" />
	<input type="button" class="materialike-media-button" value="<?php _e( 'Set Media', 'materialike' ); ?>" data-mtype="<?php echo $mtype; ?>" data-mtitle="<?php _e( 'Media', 'materialike' ); ?>" data-mselect="<?php _e( 'Select', 'materialike' ); ?>" />
	<input type="button" class="materialike-media-button-delete" value="<?php _e( 'Delete Media', 'materialike' ); ?>" />
	<div class="materialike-media-separater"></div>
	<div class="materialike-media-display" data-message="<?php _e( 'Media will be showed here.', 'materialike' ); ?>" style="padding-top:10px;padding-bottom:10px;">
<?php if ( isset( $value ) && '' != $value && preg_match( '~\.mp4$|\.webm$~', wp_get_attachment_url( $value ) ) ) : $media = get_attached_file( esc_html( $value ) ); ?>
		<span><span class="dashicons dashicons-video-alt2"></span>&nbsp;<?php echo substr( $media, strrpos( $media, '/' ) + 1 ); ?></span>
<?php elseif ( isset( $value ) && '' != $value ) : $image = wp_get_attachment_image_src( esc_html( $value ), 'full' ); ?>
		<img src="<?php echo $image[0]; ?>" />
<?php else: ?>		
		<span class="dashicons dashicons-images-alt2"></span>&nbsp;<?php _e( 'Media will be showed here.', 'materialike' ); ?>
<?php endif; ?>		
	</div>
</div>
<?php

}

/*
 * Set Color Picker
 */
function materialike_set_color_picker( $name = '', $value = '' ) {

?>
<input type="text" name="<?php echo $name; ?>" value="<?php echo $value; ?>" class="color-picker" />
<?php

}

/*
 * Set Input
 */
function materialike_set_input( $name = '', $value = '' ) {

?>
<input type="text" name="<?php echo $name; ?>" value="<?php echo esc_html( $value ); ?>" class="field-text" />
<?php

}

/*
 * Set Textarea
 */
function materialike_set_textarea( $name = '', $value = '' ) {

?>
<textarea name="<?php echo $name; ?>" class="field-textarea"><?php echo esc_html( $value ); ?></textarea>
<?php

}

/*
 * Set Select
 */
function materialike_set_select( $array = '', $name = '', $value = '' ) {

	$array = is_array( $array ) ? $array : array();

?>
<select name="<?php echo $name ?>" class="field-select">
<?php foreach ( $array as $key => $val ) : ?>
	<option value="<?php echo esc_html( $key ); ?>"<?php
		if( $key == $value )
			echo ' selected="selected"'; ?>><?php _e( esc_html( $val ), 'materialike' ); ?></option>
<?php endforeach; ?>
<select>
<?php

}

/*
 * Set Radio
 */
function materialike_set_radio( $array = '', $name = '', $value = '' ) {

	$array = is_array( $array ) ? $array : array();

?>
<?php foreach ( $array as $key => $val ) : ?>
<label class="field-label"><input type="radio" name="<?php echo $name ?>" value="<?php echo esc_html( $key ); ?>" class="field-radio"<?php
	if( $key == $value )
		echo ' checked="checked"'; ?> /><?php _e( esc_html( $val ), 'materialike' ); ?></label>
<?php endforeach; ?>
<?php

}

/*
 * Set Checkbox
 */
function materialike_set_checkbox( $array = '', $name = '', $value = '' ) {

	$array = is_array( $array ) ? $array : array();
	$value = is_array( $value ) ? $value : array();

?>
<?php foreach ( $array as $key => $val ) : ?>
<label class="field-label"><input type="checkbox" name="<?php echo $name ?>[]" value="<?php echo esc_html( $key ); ?>" class="field-checkbox"<?php
	if( false !== array_search( $key, $value ) )
		echo ' checked="checked"'; ?> /><?php _e( esc_html( $val ), 'materialike' ); ?></label>
<?php endforeach; ?>
<?php

}

/*
 * Register Options Setting
 */
function materialike_option_register_setting() {

	// register_setting('materialike_add_theme_options', 'materialike_add_theme_options');
    register_setting( 'reading', 'materialike_show_comments' );

}
add_action( 'admin_init', 'materialike_option_register_setting' );

/*
 * Add Setting Field
 */
function materialike_add_setting_field() {

	add_settings_field(
		'materialike_option_show_comments',
		__( 'Show Comments', 'materialike' ),
		'materialike_views_show_comments',
		'reading',
		'default',
		array( 'label_for' => 'comments-holder' )
	);

}
add_filter( 'admin_init', 'materialike_add_setting_field' );

/*
 * Add Theme Options
 */
function materialike_add_theme_options() {

	add_submenu_page(
		'themes.php',
		__( 'Theme Options', 'materialike' ),
		__( 'Theme Options', 'materialike' ),
		'manage_options',
		'materialike_theme_options',
		'materialike_views_theme_options'
	);

}
add_action('admin_menu', 'materialike_add_theme_options');

/*
 * Views Show Comments
 */
function materialike_views_show_comments() {

	$status = get_option( 'materialike_show_comments' ) ? get_option( 'materialike_show_comments' ) : 'enable';

	require(dirname(__FILE__) . '/theme-views-show-comments.php');

}

/*
 * Views Theme Options
 */
function materialike_views_theme_options() {

	materialike_save_theme_options( materialike_define_theme_options() );

	$define = materialike_define_theme_options();

	if( ! empty( $_POST ) )
		echo '<div id="setting-error-settings_updated" class="updated settings-error notice is-dismissible" style="margin-left:0;"><p><strong>' . __( 'Saved.', 'materialike' ) . '</strong></p></div>';

	require(dirname(__FILE__) . '/theme-views-options.php');

}

/*
 * Save Theme Options
 */
function materialike_save_theme_options( $define = false ) {

	if ( is_admin() && $define ) {

		foreach ( $define as $key => $val ) {

			if( isset( $_POST[$define[$key]['name']] ) )
				set_theme_mod( $define[$key]['name'], stripslashes( $_POST[$define[$key]['name']] ) );
			elseif ( 0 < count( $_POST ) )
				set_theme_mod( $define[$key]['name'], '' );

		}

	}

}

/*
 * Define Theme Options
 */
function materialike_define_theme_options() {

	$define = array(
		'headscript' => array(
			'name'  => 'headscript',
			'value' => get_theme_mod( 'headscript', '' ),
		),
		'description' => array(
			'name'  => 'description',
			'value' => get_theme_mod( 'description', '' ),
		),
		'description_show' => array(
			'name'  => 'description_show',
			'value' => get_theme_mod( 'description_show', 'show' ),
		),
		'logoafter' => array(
			'name'  => 'logoafter',
			'value' => get_theme_mod( 'logoafter', 'show' ),
		),
		'copyright' => array(
			'name'  => 'copyright',
			'value' => get_theme_mod( 'copyright', '' ),
		),
		'headscript' => array(
			'name'  => 'headscript',
			'value' => get_theme_mod( 'headscript', '' ),
		),
		'about' => array(
			'name'  => 'about',
			'value' => get_theme_mod( 'about', '' ),
		),

		'frontpage' => array(
			'name'  => 'frontpage',
			'value' => get_theme_mod( 'frontpage', 'show' ),
		),
		'main_show' => array(
			'name'  => 'main_show',
			'value' => get_theme_mod( 'main_show', 'yes' ),
		),
		'main_image' => array(
			'name'  => 'main_image',
			'value' => get_theme_mod( 'main_image', '' ),
		),
		'main_title' => array(
			'name'  => 'main_title',
			'value' => get_theme_mod( 'main_title', '' ),
		),
		'main_sentence' => array(
			'name'  => 'main_sentence',
			'value' => get_theme_mod( 'main_sentence', '' ),
		),
		'main_link' => array(
			'name'  => 'main_link',
			'value' => get_theme_mod( 'main_link', '' ),
		),
		'main_button' => array(
			'name'  => 'main_button',
			'value' => get_theme_mod( 'main_button', '' ),
		),
		'threepoint_show' => array(
			'name'  => 'threepoint_show',
			'value' => get_theme_mod( 'threepoint_show', 'yes' ),
		),
		'threepoint_1_image' => array(
			'name'  => 'threepoint_1_image',
			'value' => get_theme_mod( 'threepoint_1_image', '' ),
		),
		'threepoint_1_caption' => array(
			'name'  => 'threepoint_1_title',
			'value' => get_theme_mod( 'threepoint_1_title', '' ),
		),
		'threepoint_1_sentence' => array(
			'name'  => 'threepoint_1_sentence',
			'value' => get_theme_mod( 'threepoint_1_sentence', '' ),
		),
		'threepoint_1_link' => array(
			'name'  => 'threepoint_1_link',
			'value' => get_theme_mod( 'threepoint_1_link', '' ),
		),
		'threepoint_2_image' => array(
			'name'  => 'threepoint_2_image',
			'value' => get_theme_mod( 'threepoint_2_image', '' ),
		),
		'threepoint_2_caption' => array(
			'name'  => 'threepoint_2_caption',
			'value' => get_theme_mod( 'threepoint_2_caption', '' ),
		),
		'threepoint_2_sentence' => array(
			'name'  => 'threepoint_2_sentence',
			'value' => get_theme_mod( 'threepoint_2_sentence', '' ),
		),
		'threepoint_2_link' => array(
			'name'  => 'threepoint_2_link',
			'value' => get_theme_mod( 'threepoint_2_link', '' ),
		),
		'threepoint_3_image' => array(
			'name'  => 'threepoint_3_image',
			'value' => get_theme_mod( 'threepoint_3_image', '' ),
		),
		'threepoint_3_caption' => array(
			'name'  => 'threepoint_3_caption',
			'value' => get_theme_mod( 'threepoint_3_caption', '' ),
		),
		'threepoint_3_sentence' => array(
			'name'  => 'threepoint_3_sentence',
			'value' => get_theme_mod( 'threepoint_3_sentence', '' ),
		),
		'threepoint_3_link' => array(
			'name'  => 'threepoint_3_link',
			'value' => get_theme_mod( 'threepoint_3_link', '' ),
		),
		'cross_1_show' => array(
			'name'  => 'cross_1_show',
			'value' => get_theme_mod( 'cross_1_show', '' ),
		),
		'cross_1_image' => array(
			'name'  => 'cross_1_image',
			'value' => get_theme_mod( 'cross_1_image', '' ),
		),
		'cross_1_title' => array(
			'name'  => 'cross_1_title',
			'value' => get_theme_mod( 'cross_1_title', '' ),
		),
		'cross_1_sentence' => array(
			'name'  => 'cross_1_sentence',
			'value' => get_theme_mod( 'cross_1_sentence', '' ),
		),
		'cross_2_show' => array(
			'name'  => 'cross_2_show',
			'value' => get_theme_mod( 'cross_2_show', '' ),
		),
		'cross_2_image' => array(
			'name'  => 'cross_2_image',
			'value' => get_theme_mod( 'cross_2_image', '' ),
		),
		'cross_2_title' => array(
			'name'  => 'cross_2_title',
			'value' => get_theme_mod( 'cross_2_title', '' ),
		),
		'cross_2_sentence' => array(
			'name'  => 'cross_2_sentence',
			'value' => get_theme_mod( 'cross_2_sentence', '' ),
		),
		'cross_3_show' => array(
			'name'  => 'cross_3_show',
			'value' => get_theme_mod( 'cross_3_show', '' ),
		),
		'cross_3_image' => array(
			'name'  => 'cross_3_image',
			'value' => get_theme_mod( 'cross_3_image', '' ),
		),
		'cross_3_title' => array(
			'name'  => 'cross_3_title',
			'value' => get_theme_mod( 'cross_3_title', '' ),
		),
		'cross_3_sentence' => array(
			'name'  => 'cross_3_sentence',
			'value' => get_theme_mod( 'cross_3_sentence', '' ),
		),
		'cross_4_show' => array(
			'name'  => 'cross_4_show',
			'value' => get_theme_mod( 'cross_4_show', '' ),
		),
		'cross_4_image' => array(
			'name'  => 'cross_4_image',
			'value' => get_theme_mod( 'cross_4_image', '' ),
		),
		'cross_4_title' => array(
			'name'  => 'cross_4_title',
			'value' => get_theme_mod( 'cross_4_title', '' ),
		),
		'cross_4_sentence' => array(
			'name'  => 'cross_4_sentence',
			'value' => get_theme_mod( 'cross_4_sentence', '' ),
		),
		'entries_show' => array(
			'name'  => 'entries_show',
			'value' => get_theme_mod( 'entries_show', '' ),
		),
		'entries_title' => array(
			'name'  => 'entries_title',
			'value' => get_theme_mod( 'entries_title', '' ),
		),
		'below_entries_title' => array(
			'name'  => 'below_entries_title',
			'value' => get_theme_mod( 'below_entries_title', '' ),
		),

		'post_image' => array(
			'name'  => 'post_image',
			'value' => get_theme_mod( 'post_image', '' ),
		),
		'page_image' => array(
			'name'  => 'page_image',
			'value' => get_theme_mod( 'page_image', '' ),
		),
		'categories_image' => array(
			'name'  => 'categories_image',
			'value' => get_theme_mod( 'categories_image', '' ),
		),
		'tags_image' => array(
			'name'  => 'tags_image',
			'value' => get_theme_mod( 'tags_image', '' ),
		),
		'terms_image' => array(
			'name'  => 'terms_image',
			'value' => get_theme_mod( 'terms_image', '' ),
		),
		'attachment_image' => array(
			'name'  => 'attachment_image',
			'value' => get_theme_mod( 'attachment_image', '' ),
		),
		'archive_image' => array(
			'name'  => 'archive_image',
			'value' => get_theme_mod( 'archive_image', '' ),
		),
		'search_image' => array(
			'name'  => 'search_image',
			'value' => get_theme_mod( 'search_image', '' ),
		),
		'404_image' => array(
			'name'  => '404_image',
			'value' => get_theme_mod( 'search_image', '' ),
		),
		'post_more' => array(
			'name'  => 'post_more',
			'value' => get_theme_mod( 'post_more', '' ),
		),
		'post_end' => array(
			'name'  => 'post_end',
			'value' => get_theme_mod( 'post_end', '' ),
		),
		'voc_more' => array(
			'name'  => 'voc_more',
			'value' => get_theme_mod( 'voc_more', '' ),
		),
		'voc_detail' => array(
			'name'  => 'voc_detail',
			'value' => get_theme_mod( 'voc_detail', '' ),
		),
		'voc_readmore' => array(
			'name'  => 'voc_readmore',
			'value' => get_theme_mod( 'voc_readmore', '' ),
		),
		'voc_whatsearch' => array(
			'name'  => 'voc_whatsearch',
			'value' => get_theme_mod( 'voc_whatsearch', '' ),
		),
	);

	return $define;

}
