/**
 * Materialike Script Ripple
 *
 * @package Materialike
 * @subpackage Materialike
 * @since Materialike
 */

(function($){

	$.fn.ripple = function(options){
		var option = {
		};
		var static = {
			canvas: 'ripple-canvas',
			wave: 'ripple-wave',
			clickable: 'clickable',
		};
		var config = $.extend(option, options);
		var inc = $(this), time = null;
		var ua = window.navigator.userAgent.toLowerCase();

		var ripple = (function(){
			return{
				init: function(){
					this.clickable();
					this.clip();
				},
				calc: function(e, target){
					var plate = {
						rideX: e.pageX - target.offset().left,
						rideY: e.pageY - target.offset().top,
						sizeX: target.outerWidth(),
						sizeY: target.outerHeight(),
						shapeX: 0,
						shapeY: 0
					};

					plate.shapeX = plate.rideX - (plate.sizeX / 2);
					plate.shapeX = (plate.shapeX < 0) ? plate.shapeX * -1 : plate.shapeX;
					plate.shapeX = (plate.sizeX + plate.shapeX) * 1.414;

					plate.shapeY = plate.rideY - (plate.sizeY / 2);
					plate.shapeY = (plate.shapeY < 0) ? plate.shapeY * -1 : plate.shapeY;
					plate.shapeY = (plate.sizeY + plate.shapeY) * 1.414;

					return plate;
				},
				draw: function(e, target){
					var plate = this.calc(e, target);
					var size = (plate.shapeX <= plate.shapeY) ? plate.shapeY :  plate.shapeX;
					var margin = size / 2 * -1;
					target.children('.' + static.canvas).remove();
					target.prepend('<span class="' + static.canvas + '" />');
					target.children('.' + static.canvas).append('<span class="' + static.wave + '" style="width:' + size + 'px;height:' + size + 'px;left:' + plate.rideX + 'px;top:' + plate.rideY + 'px;margin-left:' + margin + 'px;margin-top:' + margin + 'px;" />');
					clearTimeout(time);
					time = setTimeout(function(){
						target.children('.' + static.canvas).children('.' + static.wave).css({
							'transform': 'scale(1, 1)'
						});
					}, 1 / 1000);
				},
				hidden: function(target){
					time = setTimeout(function(){
						target.children('.' + static.canvas).children('.' + static.wave).css({
							'opacity': 0
						});
						clearTimeout(time);
					}, 1 / 1000);
				},
				dcase: function(){
					if(ua.indexOf('windows') > -1 || ua.indexOf('macintosh') > -1){
						return true;
					}else{
						return false;
					}
				},
				clickable: function(){
					inc.append('<span class="' + static.clickable + '" />');
				},
				clip: function(){
					inc.bind({
						mouseout: function(){
							if(ripple.dcase()){
								ripple.hidden($(this));
							}
						},
						mousedown: function(e){
							if(ripple.dcase()){
								if(e.which === 1){
									ripple.draw(e, $(this));
								}
							}
						},
						mouseup: function(e){
							if(ripple.dcase()){
								if(e.which === 1){
									ripple.hidden($(this));
								}
							}
						},
						touchstart: function(e){
							if(!ripple.dcase()){
								ripple.draw(e.originalEvent.touches[0], $(this));
							}
						},
						touchend: function(e){
							if(!ripple.dcase()){
								ripple.hidden($(this));
							}
						}
					});
				}
			};
		})();

		ripple.init();

		return(this);
	};

})(jQuery);
